summaryrefslogtreecommitdiff
path: root/randr/rrmonitor.c
diff options
context:
space:
mode:
authorDave Airlie <airlied@redhat.com>2020-07-06 07:00:50 +1000
committerDave Airlie <airlied@redhat.com>2020-07-10 06:17:44 +1000
commitea47af87f692b291a988834c6f14d73a08cb1d75 (patch)
tree59de9a428349deb2f920d94048eb11e7ab6633ee /randr/rrmonitor.c
parent15b7738389b36ec2739d4f599539bcb7c2be89a1 (diff)
xserver/output: rename some badly named variables/APIs.
This is an API and ABI break Reviewed-by: Peter Hutterer <peter.hutterer@who-t.net>
Diffstat (limited to 'randr/rrmonitor.c')
-rw-r--r--randr/rrmonitor.c36
1 files changed, 18 insertions, 18 deletions
diff --git a/randr/rrmonitor.c b/randr/rrmonitor.c
index 1bb5018fe..e62bd484d 100644
--- a/randr/rrmonitor.c
+++ b/randr/rrmonitor.c
@@ -195,21 +195,21 @@ RRMonitorInitList(ScreenPtr screen, RRMonitorListPtr mon_list, Bool get_active)
rrScrPrivPtr pScrPriv = rrGetScrPriv(screen);
int m, o, c, sc;
int numCrtcs;
- ScreenPtr slave;
+ ScreenPtr secondary;
if (!RRGetInfo(screen, FALSE))
return FALSE;
/* Count the number of crtcs in this and any slave screens */
numCrtcs = pScrPriv->numCrtcs;
- xorg_list_for_each_entry(slave, &screen->slave_list, slave_head) {
- rrScrPrivPtr pSlavePriv;
+ xorg_list_for_each_entry(secondary, &screen->secondary_list, secondary_head) {
+ rrScrPrivPtr pSecondaryPriv;
- if (!slave->is_output_slave)
+ if (!secondary->is_output_secondary)
continue;
- pSlavePriv = rrGetScrPriv(slave);
- numCrtcs += pSlavePriv->numCrtcs;
+ pSecondaryPriv = rrGetScrPriv(secondary);
+ numCrtcs += pSecondaryPriv->numCrtcs;
}
mon_list->num_crtcs = numCrtcs;
@@ -224,16 +224,16 @@ RRMonitorInitList(ScreenPtr screen, RRMonitorListPtr mon_list, Bool get_active)
mon_list->server_crtc[c] = pScrPriv->crtcs[sc];
}
- xorg_list_for_each_entry(slave, &screen->slave_list, slave_head) {
- rrScrPrivPtr pSlavePriv;
+ xorg_list_for_each_entry(secondary, &screen->secondary_list, secondary_head) {
+ rrScrPrivPtr pSecondaryPriv;
- if (!slave->is_output_slave)
+ if (!secondary->is_output_secondary)
continue;
- pSlavePriv = rrGetScrPriv(slave);
- for (sc = 0; sc < pSlavePriv->numCrtcs; sc++, c++) {
- if (pSlavePriv->crtcs[sc]->mode != NULL)
- mon_list->server_crtc[c] = pSlavePriv->crtcs[sc];
+ pSecondaryPriv = rrGetScrPriv(secondary);
+ for (sc = 0; sc < pSecondaryPriv->numCrtcs; sc++, c++) {
+ if (pSecondaryPriv->crtcs[sc]->mode != NULL)
+ mon_list->server_crtc[c] = pSecondaryPriv->crtcs[sc];
}
}
@@ -464,7 +464,7 @@ RRMonitorAdd(ClientPtr client, ScreenPtr screen, RRMonitorPtr monitor)
{
rrScrPrivPtr pScrPriv = rrGetScrPriv(screen);
int m;
- ScreenPtr slave;
+ ScreenPtr secondary;
RRMonitorPtr *monitors;
if (!pScrPriv)
@@ -479,11 +479,11 @@ RRMonitorAdd(ClientPtr client, ScreenPtr screen, RRMonitorPtr monitor)
return BadValue;
}
- xorg_list_for_each_entry(slave, &screen->slave_list, slave_head) {
- if (!slave->is_output_slave)
+ xorg_list_for_each_entry(secondary, &screen->secondary_list, secondary_head) {
+ if (!secondary->is_output_secondary)
continue;
- if (RRMonitorMatchesOutputName(slave, monitor->name)) {
+ if (RRMonitorMatchesOutputName(secondary, monitor->name)) {
client->errorValue = monitor->name;
return BadValue;
}
@@ -195,21 +195,21 @@ RRMonitorInitList(ScreenPtr screen, RRMonitorListPtr mon_list, Bool get_active)
if (!RRGetInfo(screen, FALSE))
return FALSE;
- /* Count the number of crtcs in this and any slave screens */
+ /* Count the number of crtcs in this and any secondary screens */
numCrtcs = pScrPriv->numCrtcs;